==> zio-aws-ec2_2.12-5.17.145.1-sources.jar: zio/aws/ec2/model/DescribeTransitGatewayRouteTablesResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeTransitGatewayRouteTablesResponse(
    transitGatewayRouteTables: Option[
      Iterable[zio.aws.ec2.model.TransitGatewayRouteTable]
    ] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayRouteTablesResponse = {
    import DescribeTransitGatewayRouteTablesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayRouteTablesResponse
      .builder()
      .optionallyWith(
        transitGatewayRouteTables.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.transitGatewayRouteTables)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse.ReadOnly =
    zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse
      .wrap(buildAwsValue())
}
object DescribeTransitGatewayRouteTablesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayRouteTablesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse =
      zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse(
        transitGatewayRouteTables.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def transitGatewayRouteTables
        : Option[List[zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly]]
    def nextToken: Option[String]
    def getTransitGatewayRouteTables: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "transitGatewayRouteTables",
      transitGatewayRouteTables
    )
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayRouteTablesResponse
  ) extends zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse.ReadOnly {
    override val transitGatewayRouteTables
        : Option[List[zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly]] =
      scala
        .Option(impl.transitGatewayRouteTables())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.TransitGatewayRouteTable.wrap(item)
          }.toList
        )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayRouteTablesResponse
  ): zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.295.22-sources.jar: zio/aws/ec2/model/DescribeTransitGatewayRouteTablesResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeTransitGatewayRouteTablesResponse(
    transitGatewayRouteTables: Optional[
      Iterable[zio.aws.ec2.model.TransitGatewayRouteTable]
    ] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayRouteTablesResponse = {
    import DescribeTransitGatewayRouteTablesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayRouteTablesResponse
      .builder()
      .optionallyWith(
        transitGatewayRouteTables.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.transitGatewayRouteTables)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse.ReadOnly =
    zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse
      .wrap(buildAwsValue())
}
object DescribeTransitGatewayRouteTablesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayRouteTablesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse =
      zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse(
        transitGatewayRouteTables.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def transitGatewayRouteTables
        : Optional[List[zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly]]
    def nextToken: Optional[String]
    def getTransitGatewayRouteTables: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "transitGatewayRouteTables",
      transitGatewayRouteTables
    )
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayRouteTablesResponse
  ) extends zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse.ReadOnly {
    override val transitGatewayRouteTables
        : Optional[List[zio.aws.ec2.model.TransitGatewayRouteTable.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitGatewayRouteTables())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.TransitGatewayRouteTable.wrap(item)
          }.toList
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTransitGatewayRouteTablesResponse
  ): zio.aws.ec2.model.DescribeTransitGatewayRouteTablesResponse.ReadOnly =
    new Wrapper(impl)
}
